%%  This function plots the outputs of the AMR model for debugging.  Four
%%  plots are created: volumetric flowrate vs. time, magnetic field vs 
%%  time, Temp vs. time, and Temp vs. distance

function resplot(time,x,Ts,Tf,mdot,muoH,dr,rhof)
[Nx Nt]=size(Ts);
tau=time(Nt)
dt=tau/Nt;

figure(1)
subplot(2,1,1)
Vdot=mdot/rhof;
plot(time(1:Nt-1),Vdot)
xlabel 'Time (s)'
ylabel 'Volumetric flow rate (L/s)'

subplot(2,1,2)
hold off
plot(time,muoH(1,1:Nt))
hold on
plot(time,muoH(floor(Nx/2),1:Nt),':')
plot(time,muoH(Nx,1:Nt),'k')
legend('hot end','middle','cold end')
ylabel 'Magnetic field (Tesla)'
xlabel 'Time (s)'

figure(2)
plot(Tf(1,:),'k')
hold on 
plot(Tf(Nx/2,:),'b')
plot(Tf(Nx,:),'r')
xlabel 'Time (s)'
ylabel 'Fluid Temperature (K)'
grid on
hold off

t0=0;
t1=dr*tau/2;
t2=(1-dr)*tau/4+dr*tau/2;
t3=tau/2;
t4=tau/2+dr*tau/2;
t5=tau/2+dr*tau/2+(1-dr)*tau/4;

figure(3)
plot(x,Tf(:,1),'k')
xlabel 'Axial location (m)'
ylabel 'Fluid Temperature (K)'
grid on
hold on
for i=1:Nt-1
    if abs(time(i)-t1)<dt/1.5
        plot(x,Tf(:,i))
    end
    if abs(time(i)-t2)<dt/1.5
        plot(x,Tf(:,i),'r')
    end
    if abs(time(i)-t3)<dt/1.5
        plot(x,Tf(:,i),'g')
    end
    if abs(time(i)-t4)<dt/1.5
        plot(x,Tf(:,i),'m')
    end
    if abs(time(i)-t5)<dt/1.5
        plot(x,Tf(:,i),'b*')
    end
end
plot(x,Tf(:,Nt-1),'kx')
legend('end of H-C blow','beginning of C-H blow','middle of C-H blow','end of C-H blow','beginning of H-C blow','middle of H-C blow','t=tau')
hold off
    